@@ -5,4 +5,5 @@ Created on Wed Aug 25 09:43:25 2021
 
 @author: mike
 """
-from .grid import Grid
+from .grid import Grid, Processor
+from . import processors
\ No newline at end of file
