@@ -205,11 +205,15 @@ class Processor(object):
         if isinstance(data_path, str):
             grid1 = xr.open_mfdataset(data_path, chunks=chunks, parallel=parallel, preprocess=preprocessor)
 
-            ## create unique hash and new path
-            # run_id = uuid4().hex
-
-            # base_path = os.path.split(data_path)[0]
-            # grid_path = os.path.join(base_path, run_id + '.nc')
+        elif isinstance(data_path, list):
+            if isinstance(data_path[0], str):
+                paths = []
+                [paths.extend(glob(p)) for p in data_path]
+                paths.sort()
+                grid1 = xr.open_mfdataset(paths, chunks=chunks, parallel=parallel, preprocess=preprocessor)
+                data_path = paths.copy()
+            else:
+                raise TypeError('If data_path is a list, then it must be a list of str paths.')
 
         elif isinstance(data_path, xr.Dataset):
             grid1 = data_path
@@ -252,6 +256,9 @@ class Processor(object):
         ## Checks
         grid_checks(self._dims)
 
+        if not os.path.exists(output_path):
+            os.makedirs(output_path)
+
         ## some nice processing
         if not hasattr(self, '_null_grid'):
             self._extract_null_grid()
@@ -404,7 +411,7 @@ class Processor(object):
 
             [ds.update({'grouping': 'blocks'}) for ds in dataset_list]
 
-            sizes_sqr = np.arange(1, xy_size+2)**2 - 1
+            # sizes_sqr = np.arange(1, xy_size+2)**2 - 1
 
             pts_df = self._select_sample_points(samples1)
 
@@ -417,7 +424,7 @@ class Processor(object):
         obj_dict = {'xy_size': xy_size, 'mean_obj_size': mean_size, 'max_obj_size': max(obj_sizes), 'min_obj_size': min(obj_sizes), 'sum_obj_size': mean_size * n_stns, 'n_stations': n_stns}
         self._obj_dict = obj_dict
 
-        ds_list = self.load_grid_metadata(dataset_list)
+        _ = self.load_dataset_metadata(dataset_list)
 
         grid1.close()
         grid1 = None
@@ -491,7 +498,7 @@ class Grid(Titan):
         return dataset_list
 
 
-    def load_results(self, results, xy_size, dataset_id=None, sum_closed='right', other_closed='left', discrete=True, other_attrs=None, other_encoding=None, run_date=None, skip_resampling=True):
+    def load_grid_results(self, results, xy_size, dataset_id=None, sum_closed='right', other_closed='left', discrete=True, other_attrs=None, other_encoding=None, run_date=None, skip_resampling=True):
         """
 
         """
@@ -499,8 +506,10 @@ class Grid(Titan):
         paths = None
         if isinstance(results, list):
             if isinstance(results[0], str):
-                paths = results
-                data_list = [xr.open_dataset(p) for p in results if isinstance(p, str)]
+                paths = []
+                [paths.extend(glob(p)) for p in results]
+                paths.sort()
+                data_list = [xr.open_dataset(p) for p in paths if isinstance(p, str)]
             elif isinstance(results[0], xr.Dataset):
                 data_list = [xr.open_dataset(p) for p in results if isinstance(p, xr.Dataset)]
             else:
@@ -527,7 +536,7 @@ class Grid(Titan):
                 raise TypeError('If paths are not contained in results, then a dataset_id of a str must be passed.')
 
         ## Iterate through the datasets
-        load_results = super().load_results
+        # load_results = self.load_results
 
 
         for ds_id, data_list in data_dict.items():
@@ -547,7 +556,7 @@ class Grid(Titan):
             #     for block in blocks:
             #         load_results(block, ds_id, sum_closed=sum_closed, other_closed=other_closed, discrete=discrete, other_attrs=other_attrs, other_encoding=other_encoding, run_date=run_date, ignore_resampling=ignore_resampling)
 
-            n_files = len((data_list))
+            n_files = len(data_list)
 
             for i, data in enumerate(data_list):
                 print(str(i+1) + ' of ' + str(n_files) + ' chunks')
@@ -561,7 +570,13 @@ class Grid(Titan):
                 data1 = None
 
                 for block in blocks:
-                    load_results(block, ds_id, sum_closed=sum_closed, other_closed=other_closed, discrete=discrete, other_attrs=other_attrs, other_encoding=other_encoding, run_date=run_date, skip_resampling=skip_resampling)
+                    # Determine if all values are null
+                    total_n_values = np.prod(list(block.dims.values()))
+                    t1 = block.isnull().sum()
+                    n_null = max([int(t1[t].values) for t in t1])
+
+                    if n_null < total_n_values:
+                        self.load_results(block, ds_id, sum_closed=sum_closed, other_closed=other_closed, discrete=discrete, other_attrs=other_attrs, other_encoding=other_encoding, run_date=run_date, skip_resampling=skip_resampling)
 
 
             # with concurrent.futures.ProcessPoolExecutor(max_workers=max_workers) as executor:
