@@ -44,7 +44,7 @@ def convert_site_names(names, rem_m=True):
     return names2
 
 
-def get_hilltop_results(param, station_mtype_corrections=None, quality_codes=True, public_url=None, save_interval_hours=336, modified_date=True, local_tz='Etc/GMT-12'):
+def get_hilltop_results(param, station_mtype_corrections=None, quality_codes=True, public_url=None, save_interval_hours=336, modified_date=True, local_tz='Etc/GMT-12', add_ref_as_name=False):
     """
 
     """
@@ -88,6 +88,9 @@ def get_hilltop_results(param, station_mtype_corrections=None, quality_codes=Tru
             stns2 = stns1[(stns1.lat > -47.5) & (stns1.lat < -34) & (stns1.lon > 166) & (stns1.lon < 179)].dropna().copy()
             stns2.rename(columns={'SiteName': 'ref'}, inplace=True)
 
+            if add_ref_as_name:
+                stns2['name'] = stns2['ref']
+
             ## Process stations
             stns3 = tu.processing.process_stations_df(stns2, datasets[meas][0]['dataset_id'], file_remote)
 
@@ -139,14 +142,14 @@ def get_hilltop_results(param, station_mtype_corrections=None, quality_codes=Tru
                             # sleep(1)
                             if row.Measurement == 'Abstraction Volume':
                                 if row['corrections']:
-                                    ts_data = ws.get_data(base_url, hts, row.ref, row.Measurement, from_date=str(row.From), to_date=str(row.To), agg_method='Total', agg_interval='1 day')[1:]
+                                    ts_data1 = ws.get_data(base_url, hts, row.ref, row.Measurement, from_date=str(row.From), to_date=str(row.To), agg_method='Total', agg_interval='1 day')[1:]
                                 else:
-                                    ts_data = ws.get_data(base_url, hts, row.ref, row.Measurement, agg_method='Total', agg_interval='1 day')[1:]
+                                    ts_data1 = ws.get_data(base_url, hts, row.ref, row.Measurement, agg_method='Total', agg_interval='1 day')[1:]
                             else:
                                 if row['corrections']:
-                                    ts_data = ws.get_data(base_url, hts, row.ref, row.Measurement, from_date=str(row.From), to_date=str(row.To), quality_codes=quality_codes, dtl_method='half')
+                                    ts_data1 = ws.get_data(base_url, hts, row.ref, row.Measurement, from_date=str(row.From), to_date=str(row.To), quality_codes=quality_codes, dtl_method='half')
                                 else:
-                                    ts_data = ws.get_data(base_url, hts, row.ref, row.Measurement, quality_codes=quality_codes, dtl_method='half')
+                                    ts_data1 = ws.get_data(base_url, hts, row.ref, row.Measurement, quality_codes=quality_codes, dtl_method='half')
 
                             break
                         except requests.exceptions.ConnectionError as err:
@@ -170,12 +173,12 @@ def get_hilltop_results(param, station_mtype_corrections=None, quality_codes=Tru
 
                     ## Pre-process time series data
                     parameter = datasets[meas][0]['parameter']
-                    ts_data1 = ts_data.reset_index().rename(columns={'DateTime': 'time', 'Value': parameter, 'QualityCode': 'quality_code'}).drop(['Site', 'Measurement'], axis=1)
+                    ts_data1 = ts_data1.reset_index().rename(columns={'DateTime': 'time', 'Value': parameter, 'QualityCode': 'quality_code'}).drop(['Site', 'Measurement'], axis=1)
 
                     if (row['Measurement'] == 'Water Level') and (row['Units'] == 'mm'):
-                        ts_data1[parameter] = pd.to_numeric(ts_data1[parameter], errors='ignore') * 0.001
+                        ts_data1[parameter] = pd.to_numeric(ts_data1[parameter].values, errors='ignore') * 0.001
                     else:
-                        ts_data1[parameter] = pd.to_numeric(ts_data1[parameter], errors='ignore')
+                        ts_data1[parameter] = pd.to_numeric(ts_data1[parameter].values, errors='ignore')
 
                     ts_data1['height'] = 0
                     ts_data1['geometry'] = stn['geometry'].values[0]
@@ -187,14 +190,22 @@ def get_hilltop_results(param, station_mtype_corrections=None, quality_codes=Tru
                         mod_date = pd.Timestamp.today(tz='utc').round('s').tz_localize(None)
                         ts_data1['modified_date'] = mod_date
 
-                    obs3 = ts_data1.to_xarray()
-                    obs4 = xr.combine_by_coords([obs3, stn], data_vars='minimal')
+                    # obs3 = ts_data1.to_xarray()
+                    obs4 = xr.combine_by_coords([ts_data1.to_xarray(), stn], data_vars='minimal')
 
                     ###########################################
                     ## Package up into the data_dict
                     if not ts_data1.empty:
                         tu.processing.prepare_results(data_dict, datasets[meas], obs4, max_run_date_key, other_closed='right')
 
+                    del ts_data1
+                    # del obs3
+                    del obs4
+                    # ts_data = pd.DataFrame()
+                    ts_data1 = pd.DataFrame()
+                    # obs3 = xr.Dataset()
+                    obs4 = xr.Dataset()
+
                 ########################################
                 ### Save results and stations
                 tu.s3.update_results_s3(processing_code, data_dict, run_date_dict, remote, threads=30, public_url=public_url)
