@@ -19,7 +19,7 @@ from tethys_utils.misc import make_run_date_key, grp_ts_agg, write_pkl_zstd
 import geojson
 from shapely.geometry import shape, mapping, Point, box
 from shapely import wkb
-from tethysts import Tethys
+from tethysts import Tethys, utils
 
 ############################################
 ### Parameters
@@ -284,8 +284,16 @@ def package_xarray(data, parameter, attrs, encoding, run_date=None, compression=
 
     ## Compress if requested
     if compression:
-        cctx = zstd.ZstdCompressor(level=compress_level)
-        c_obj = cctx.compress(p_ts1)
+        while True:
+            cctx = zstd.ZstdCompressor(level=compress_level)
+            c_obj = cctx.compress(p_ts1)
+
+            # Test compression
+            try:
+                _ = utils.read_pkl_zstd(c_obj)
+                break
+            except:
+                print('ztsd compression failure.')
 
         return c_obj
     else:
