@@ -163,10 +163,15 @@ def put_remote_dataset(s3, bucket, dataset, stns, run_date=None):
 
     dataset.update(ds_stats)
 
+    ## Add version number
+    dataset.update({'version': 2})
+
+    ## Check and create dataset metadata
     ds4 = Dataset(**dataset)
 
     ds5 = orjson.loads(ds4.json(exclude_none=True))
 
+    ## Write the object
     ds_obj = write_json_zstd(ds5)
 
     ds_key = key_patterns['dataset'].format(dataset_id=dataset_id)
@@ -362,7 +367,7 @@ def compare_datasets_from_s3(conn_config, bucket, new_data, add_old=False, last_
 
         up1 = compare_xrs(xr_old_one, new_data, add_old=add_old)
     else:
-        print('No prior data found in S3. All data will be returned.')
+        # print('No prior data found in S3. All data will be returned.')
         up1 = new_data.copy()
 
     return up1
@@ -440,7 +445,7 @@ def update_results_s3(processing_code, data_dict, run_date_dict, remote, threads
                 return None
 
             stn_id = str(new1.squeeze()['station_id'].values)
-            print('station_id: ' + stn_id)
+            # print('station_id: ' + stn_id)
 
             vars1 = list(new1.variables)
             parameter = [v for v in vars1 if 'dataset_id' in new1[v].attrs][0]
@@ -655,45 +660,66 @@ def process_run_date(processing_code, dataset_list, remote, run_date=None, save_
 
 
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+# for result in results[2500:]:
+#     new1 = xr.load_dataset(read_pkl_zstd(result, False))
+#
+#     stn_id = str(new1.squeeze()['station_id'].values)
+#     print('station_id: ' + stn_id)
+#
+#     vars1 = list(new1.variables)
+#     parameter = [v for v in vars1 if 'dataset_id' in new1[v].attrs][0]
+#     result_attrs = new1[parameter].attrs.copy()
+#
+#     ds_id = result_attrs['dataset_id']
+#     mod_date_key = new1.attrs['history'].split(':')[0]
+#
+#     if no_comparison:
+#         up1 = new1
+#     else:
+#         last_date_key_df = last_date1[last_date1['station_id'] == stn_id]
+#         if last_date_key_df.empty:
+#             last_date_key = None
+#         else:
+#             last_date_key = make_run_date_key(last_date_key_df['KeyDate'].iloc[0])
+#
+#         up1 = compare_datasets_from_s3(conn_config, bucket, new1, add_old=add_old, last_run_date_key=last_date_key, public_url=public_url)
+#
+#     ## Save results
+#     if isinstance(up1, xr.Dataset) and (len(up1[parameter].time) > 0):
+#
+#         # print('Save results')
+#         key_dict = {'dataset_id': ds_id, 'station_id': stn_id, 'run_date': run_date_key}
+#
+#         new_key = key_patterns['results'].format(**key_dict)
+#
+#         cctx = zstd.ZstdCompressor(level=1)
+#         c_obj = cctx.compress(up1.to_netcdf())
+#
+#         obj_resp = s3.put_object(Body=c_obj, Bucket=bucket, Key=new_key, ContentType='application/zstd', Metadata={'run_date': mod_date_key})
+#
+#         ## Process stn data
+#         # print('Save station data')
+#
+#         ## Process object key infos
+#         stn_obj_df1 = obj_df1[obj_df1['station_id'] == stn_id].drop(['LastModified', 'station_id'], axis=1).copy()
+#         keys = stn_obj_df1['Key'].unique()
+#         new_key_info = [new_key, obj_resp['ResponseMetadata']['HTTPHeaders']['etag'].replace('"', ''), len(c_obj), pd.Timestamp(run_date_key).tz_localize(None)]
+#
+#         if new_key in keys:
+#             stn_obj_df1[stn_obj_df1['Key'] == new_key] = new_key_info
+#         else:
+#             stn_obj_df1.loc[len(stn_obj_df1)] = new_key_info
+#
+#         info1 = [S3ObjectKey(key=row['Key'], bucket=bucket, content_length=row['Size'], etag=row['ETag'], run_date=row['KeyDate']) for i, row in stn_obj_df1.iterrows()]
+#
+#         ## Final station processing and saving
+#         stn_m = process_station_summ(ds_id, stn_id, up1, info1, mod_date=mod_date_key)
+#
+#         up_stns = put_remote_station(s3, bucket, stn_m, run_date=mod_date_key)
+#
+#     else:
+#         print('No new data to update')
+#
+#     ## Get rid of big objects
+#     new1 = None
+#     up1 = None
